pub struct StateGroupRow {
label: TemplateChild<Label>,
list_box: TemplateChild<ListBox>,
group: BoundObject<GroupingListGroup>,
room: PhantomData<Option<Room>>,
read_receipts_lists: OnceCell<ListStore>,
read_receipts_list_model: OnceCell<FlattenListModel>,
has_read_receipts: PhantomData<bool>,
is_expanded: Cell<bool>,
}Fields
label: TemplateChild<Label>list_box: TemplateChild<ListBox>group: BoundObject<GroupingListGroup>The group displayed by this widget.
room: PhantomData<Option<Room>>The room containing the events of the current group.
read_receipts_lists: OnceCell<ListStore>The list model containing the read receipts lists of the children.
read_receipts_list_model: OnceCell<FlattenListModel>The list model containing all the read receiptsof the children.
has_read_receipts: PhantomData<bool>Whether this group contains read receipts.
is_expanded: Cell<bool>Whether this group is expanded.
Implementations
Sourceimpl StateGroupRow
impl StateGroupRow
Sourcefn register_type()
fn register_type()
Registers the type only once.
Sourceimpl StateGroupRow
impl StateGroupRow
Sourcefn set_group(&self, group: Option<GroupingListGroup>)
fn set_group(&self, group: Option<GroupingListGroup>)
Set the group presented by this row.
Sourcefn read_receipts_lists(&self) -> &ListStore
fn read_receipts_lists(&self) -> &ListStore
The list model containing the read receipts lists of the children.
Sourcefn read_receipts_list_model(&self) -> &FlattenListModel
fn read_receipts_list_model(&self) -> &FlattenListModel
The list model containing all the read receipts of the children.
Sourcefn read_receipts_list_model_owned(&self) -> FlattenListModel
fn read_receipts_list_model_owned(&self) -> FlattenListModel
The owned list model containing all the read receipts of the children.
Sourcefn has_read_receipts(&self) -> bool
fn has_read_receipts(&self) -> bool
Whether this group contains read receipts.
Sourcefn set_is_expanded(&self, is_expanded: bool)
fn set_is_expanded(&self, is_expanded: bool)
Set whether this row is expanded.
Sourcefn toggle_expanded(&self)
fn toggle_expanded(&self)
Toggle whether this group is expanded.
Sourcefn items_changed(&self, position: u32, removed: u32, added: u32)
fn items_changed(&self, position: u32, removed: u32, added: u32)
Handle when items changed in the underlying group.
Sourcefn update_label(&self)
fn update_label(&self)
Update the label of this row for the current state.